d3.csv(
  'https://gist.githubusercontent.com/numioguri/18d7ea134d1c1146cc55688173802b2f/raw/db9bbd8d3a3103723510127338a96dc8760c0118/.csv',
).then(function (data) {
  var width = 600;
  var height = 500;
  var radius = Math.min(width, height) / 2;

  var color = d3.scaleOrdinal(d3.schemeCategory10);

  var svg = d3
    .select('#chart')
    .append('svg')
    .attr('width', width)
    .attr('height', height);

  var arc = d3.arc().innerRadius(0).outerRadius(radius);

  var pie = d3.pie().value(function (d) {
    return d.Survived;
  });

  var arcs = svg
    .selectAll('arc')
    .data(pie(data))
    .enter()
    .append('g')
    .attr('class', 'arc')
    .attr(
      'transform',
      'translate(' + width / 2 + ',' + height / 2 + ')',
    );

  arcs
    .append('path')
    .attr('d', arc)
    .attr('fill', function (d, i) {
      return color(i);
    });

  // Add labels to the pie slices
  arcs
    .append('text')
    .attr('transform', function (d) {
      return 'translate(' + arc.centroid(d) + ')';
    })
    .attr('text-anchor', 'middle')
    .text(function (d) {
      return d.data.PassengerId;
    });

  // Legend
  var legend = svg
    .selectAll('.legend')
    .data(pie(data))
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr('transform', function (d, i) {
      return (
        'translate(' +
        (width - 150) +
        ',' +
        (i * 20 + 20) +
        ')'
      );
    });

  legend
    .append('rect')
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', function (d, i) {
      return color(i);
    });

  legend
    .append('text')
    .attr('x', 22)
    .attr('y', 9)
    .attr('dy', '.35em')
    .text(function (d) {
      return d.data.PassengerId + ': ' + d.data.Survived;
    });
});
